#
# spec file for package octave-forge-statistics
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define octpkg  statistics
Name:           octave-forge-%{octpkg}
Version:        1.6.6
Release:        1.1
Summary:        Additional statistics functions for Octave
License:        GPL-3.0-or-later AND SUSE-Public-Domain
Group:          Productivity/Scientific/Math
URL:            https://gnu-octave.github.io/packages/%{octpkg}/
Source0:        https://github.com/gnu-octave/%{octpkg}/archive/refs/tags/release-%{version}.tar.gz#/%{octpkg}-%{version}.tar.gz
BuildRequires:  octave-devel
Requires:       octave-cli >= 7.0.0

%description
Additional statistics functions.
This is part of Octave-Forge project.

%prep
%setup -q -c %{name}-%{version}
%octave_pkg_src

%build
%octave_pkg_build

%install
%octave_pkg_install

%check
%octave_pkg_test

%post
%octave --eval "pkg rebuild"

%postun
%octave --eval "pkg rebuild"

%files
%{octpackages_dir}/%{octpkg}-%{version}
%{octlib_dir}/%{octpkg}-%{version}

%changelog
* Wed Jun 12 2024 ming li <mli@suse.com>
- Update to version 1.6.6:
  * New functions:
  - editDistance
  * Improvements:
  - fillmissing: combining `movmedian` method and
    `missinglocation` option no longer ignores non-NaN values.
  - gumbelinv: fix incorrect return value due to misplaced
    minus sign
  - glmfit: fix input validation, parameter parsing,
    and update documentation
  - histfit: updated support for other distributions,
    fixed MATLAB compatibility
  - plot method for probability distribution objects partially
    implemented to allow plotting PDF and superimposing it
    over histograms of fitted data.
* Fri Mar 15 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.6.5:
  * Fixed bug in mad and median functions.
  * Fixed mean, std, and var methods for truncated
    PiecewiseLinearDistribution.
* Sat Jan 20 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.6.1:
  * New functions:
  - ClassificationKNN (new classdef)
  - predict (for ClassificationKNN classdef)
  - fitcknn
  - fitrgam
  - knnsearch (fully Matlab compatible)
  - mnrfit
  - rangesearch (fully Matlab compatible)
  - RegressionGAM (new classdef)
  - predict (for RegressionGAM classdef)
  * Improvements:
  - anovan: new features
  - friedman: bug fixes
  - pdist: updated functionality, fully MATLAB compatible
  - pdist2: updated functionality, fully MATLAB compatible
  - regress_gp: updated functionality with RBF kernel
  - ridge: bug fixes
* Thu Oct 19 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.6.0:
  * Dependency changed to Octave>=7.1.0.
  * Various distribution functions have been renamed, deprecated,
    or modified extensively so that backwards compatibility is
    broken.
  * `mad`, `mean`, `median`, `std`, `var` functions shadow core
    Octave's respective functions.
  * Incompatibility with the `nan` package
  * For full list of new, changes, deprecated, and dropped
    functions, see the NEWS file at:
    https://github.com/gnu-octave/statistics/blob/release-1.6.0/NEWS
* Mon Apr 10 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.4:
  * New functions:
  - bvtcdf
  - correlation_test (new functionality, replacing old cor_test)
  - icdf (wrapper for all available *inv distribution functions)
  - fishertest (fully Matlab compatible)
  - procrustes (fully Matlab compatible)
  - ztest2 (new functionality, replacing old prop_test_2)
  * Improvements:
  - cdf: updated wrapper for all available *cdf distribution
    functions
  - dcov: handles missing values and multivariate samples
  - geomean: fixed MATLAB compatibility
  - harmmean: fixed MATLAB compatibility
  - mean: fixed MATLAB compatibility
  - median: fixed MATLAB compatibility
  - mvtcdf: improved speed, fixed Matlab compatibility
  - pdf: updated wrapper for all available *pdf distribution
    functions
  - random: updated wrapper for all available *rnd distribution
    functions
  - regression_ttest: new functionality
  - std: fixed MATLAB compatibility
  - var: fixed MATLAB compatibility
  * Removed:
  - cor_test (replaced by correlation_test)
  - prop_test_2 (replaced by ztest2)
* Sun Feb 12 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 1.5.3:
  * New functions:
    + adtest (fully Matlab compatible)
    + hotelling_t2test (new functionality, replacing old
    hotelling_test)
    + hotelling_t2test2 (new functionality, replacing old
    hotelling_test_2)
    + regression_ftest (new functionality, replacing old
    f_test_regression)
    + regression_ttest (replacing old t_test_regression)
    + vmcdf (von Mises cummulative distribution function)
  * Improvements:
    + betacdf: added "upper" option
    + binocdf: added "upper" option
    + expcdf: added "upper" option and confidence bounds
    + geocdf: added "upper" option
    + gevcdf: added "upper" option
    + hygecdf: added "upper" option
    + laplace_cdf: updated functionality
    + laplace_inv: updated functionality
    + laplace_pdf: updated functionality
    + laplace_rnd: updated functionality
    + logistic_cdf: updated functionality
    + logistic_inv: updated functionality
    + logistic_pdf: updated functionality
    + logistic_rnd: updated functionality
    + logncdf: added "upper" option and confidence bounds
    + mean: fixed MATLAB compatibility
    + median: fixed MATLAB compatibility
    + multcompare: print PostHoc Test table
    + nbincdf: added "upper" option
    + poisscdf: added "upper" option
    + raylcdf: added "upper" option
    + std: fixed MATLAB compatibility
    + unidcdf: added "upper" option
    + unifcdf: added "upper" option
    + var: fixed MATLAB compatibility
    + vmpdf: updated functionality
    + vmrnd: updated functionality
    + wblcdf: added "upper" option and confidence bounds
  * Removed Functions:
    + anderson_darling_cdf (replaced by adtest)
    + anderson_darling_test (replaced by adtest)
    + hotelling_test (replaced by hotelling_t2test)
    + hotelling_test_2 (replaced by hotelling_t2test2)
    + f_test_regression (replaced by regression_ftest)
    + t_test_regression (replaced by regression_ttest)
* Wed Dec 28 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 1.5.2:
  * Important Notice:
    + mean, median, std, and var shadow core Octave's respective
    functions
    + incompatibility with the nan package
  * News:
    There are 3 newly introduced functions, which shadow core
    Octave functions, and another 5, which have been fixed or
    upgraded with missing features.
* Tue Dec  6 2022 Markus Ebner <info@ebner-markus.de>
- Update to version 1.5.1:
  * 27 newly introduced functions
  * another 16, which have been fixed or upgraded with missing features
- Removed obsolete patch fix-pkgadd.patch
  Reason: Fixed upstream
* Tue Nov  8 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 1.5.0:
  * dependency change to Octave>=6.1.0
  * mean shadows core Octave's respective function
  * removed dependency on io package
  * incompatibility with the nan package
  * All bugs from Savannah tracker have been addressed.
  * There are 30 newly introduced functions and another 32, which
    have been fixed or upgraded with missing features.
  * There are still 44 functions out of a total of 292 which have
    no tests.
- Add fix-pkgadd.patch
* Wed Feb 16 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.4.3:
  * New functions: anova1, kruskalwallis, cluster, clusterdata,
    confusionchart, confusionmat, cophenet, datasample,
    evalclusters, expfit, explike, gscatter, ismissing,
    inconsistent, mhsample.m, ncx2pdf, optimalleaforder.m, pca,
    rmmissing, silhouette, slicesample, wblplot.
  * Improvements:
  - anovan.m: use double instead of toascii (bug #60514)
  - binocdf: new option "upper" (bug #43721)
  - boxplot: better Matlab compatibility; several
    Matlab-compatible plot options added (OutlierTags,
    Sample_IDs, BoxWidth, Widths, BoxStyle, Positions, Labels,
    Colors) and an Octave-specific one (CapWidhts); demos added;
    texinfo improved (patch #9930)
  - auto MPG (carbig) sample dataset added from
    https://archive.ics.uci.edu/ml/datasets/Auto+MPG (patch
    [#10045]).
  - crosstab.m: make n-dimensional (patch #10014)
  - dendrogram.m: many improvements (patch #10036)
  - fitgmdist.m: fix typo in ComponentProportion (bug #59386)
  - gevfit: change orientation of results for Matlab
    compatibility (bug #47369).
  - hygepdf: avoid overflow for certain inputs (bug #35827)
  - kmeans: efficiency and compatibility tweaks (patch #10042)
  - pdist: option for squared Euclidean distance (patch #10051)
  - stepwisefit.m: give another option to select predictors
    (patch #8584) .
  - tricdf, triinv: fixes (bug #60113)
* Thu May  7 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 1.4.2:
  * canoncorr: allow more variables than observations
  * fitgmdist: return fitgmdist parameters (Bug #57917)
  * gamfit: invert parameter per docs (Bug #57849)
  * geoXXX: update docs 'number of failures (X-1)' =>
    'number of failures (X)' (Bug #57606)
  * kolmogorov_smirnov_test.m: update function handle usage from
    octave6+ (Bug #57351)
  * linkage.m: fix octave6+ parse error (Bug #57348)
  * unifrnd: changed unifrnd(a,a) to return a 0 rather than
    NaN (Bug #56342)
  * updates for usage of deprecated octave functions
- Drop obsolete
  octave-bug-50365-Wrong-distance-results-from-kmeans-and-wrong-centers.patch
* Thu Jul  4 2019 UTC - hiwatari.seiji@gmail.com
- Update to version 1.4.1:
  * update install scripts for octave 5.0 depreciated functions
  * bug fixes to the following functions:
  - pdist2.m: use max in distEucSq (Bug #50377)
  - normpdf: use eps tolerance in tests (Bug #51963)
  - fitgmdist: fix an output bug in fitgmdist
  - t_test: Set tolerance on t_test BISTS (Bug #54557)
  - gpXXXXX: change order of inputs to match matlab (Bug #54009)
  - bartlett_test: df = k-1 (Bug #45894)
  - gppdf: apply scale factor (Bug #54009)
  - gmdistribution: updates for bug #54278, ##54279
  - wishrnd: Bug #55860
  - Add octave-bug-50365-Wrong-distance-results-from-kmeans-and-wrong-centers.patch
* Wed Jun  6 2018 badshah400@gmail.com
- Update to version 1.4.0:
  * New functions: canoncorr, fitgmdist, gmdistribution, sigma_pts
  * The following functions have been moved from the statisctics
    package but are condtionally installed: mad
  * The following functions have been moved from octave to be
    condtionally installed:
  - BASE: cloglog, logit, prctile, probit, qqplot table
    (renamed to crosstab)
  - DISTRIBUTIONS: betacdf, betainv, betapdf, betarnd, binocdf,
    binoinv, binopdf, binornd, cauchy_cdf, cauchy_inv,
    cauchy_pdf, cauchy_rnd, chi2cdf, chi2inv, chi2pdf, chi2rnd,
    expcdf, expinv, exppdf, exprnd, fcdf, finv, fpdf, frnd,
    gamcdf, gaminv, gampdf, gamrnd, geocdf, geoinv, geopdf,
    geornd, hygecdf, hygeinv, hygepdf, hygernd,
    kolmogorov_smirnov_cdf, laplace_cdf, laplace_inv,
    laplace_pdf, laplace_rnd, logistic_cdf, logistic_inv,
    logistic_pdf, logistic_rnd, logncdf, logninv, lognpdf,
    lognrnd, nbincdf, nbininv, nbinpdf, nbinrnd, normcdf,
    norminv, normpdf, normrnd, poisscdf, poissinv, poisspdf,
    poissrnd, stdnormal_cdf, stdnormal_inv, stdnormal_pdf,
    stdnormal_rnd, tcdf, tinv, tpdf, trnd, unidcdf, unidinv,
    unidpdf, unidrnd, unifcdf, unifinv, unifpdf, unifrnd,
    wblcdf, wblinv, wblpdf, wblrnd, wienrnd.
  - MODELS: logistic_regression
  - TESTS: anova, bartlett_test, chisquare_test_homogeneity,
    chisquare_test_independence, cor_test, f_test_regression,
    hotelling_test, hotelling_test_2, kolmogorov_smirnov_test,
    kolmogorov_smirnov_test_2, kruskal_wallis_test, manova,
    mcnemar_test, prop_test_2, run_test, sign_test, t_test,
    t_test_2, t_test_regression, u_test, var_test, welch_test,
    wilcoxon_test, z_test, z_test_2.
  * Functions marked with known test failures: grp2idx: bug
    [#51928], gevfir_lmom: bug #31070.
  * Other functions that have been changed for smaller bugfixes, increased
    Matlab compatibility, or performance:
  - dcov: returned dcov instead of dcor. added demo.
  - violin: can be used with subplots. violin quality improved.
  - princomp: Fix expected values of tsquare in unit tests
  - fitgmdist: test number inputs to function
  - hist3: fix removal of rows with NaN values
  * added the packages test data to install
* Thu Nov 24 2016 dmitry_r@opensuse.org
- Update to version 1.3.0
  * Bug fixes
  * Number of new functions
* Mon Mar  9 2015 dmitry_r@opensuse.org
- Update to version 1.2.4
  * Made princomp work with nargout < 2.
  * Renamed dendogram to dendrogram.
  * Added isempty check to kmeans.
  * Transposed output of hist3.
  * Converted calculation in hmmviterbi to log space.
  * Bug fixes for stepwisefit, wishrnd.
  * Rewrite of cmdscale for improved compatibility.
  * Fix in squareform for improved compatibility.
  * New cvpartition class, with methods:
    display repartition test training
  * New sample data file fisheriris.txt for tests
  * The following functions are new:
    cdf crossval dcov pdist2 qrandn randsample signtest ttest ttest2
    vartest vartest2 ztest
* Thu Feb 26 2015 dmitry_r@opensuse.org
- Split from octave-forge package, version 1.2.3
